# Security Policy

## Reporting a Vulnerability

Please use GitHub's
[private vulnerability reporting tool](https://github.com/esi-neuroscience/acme/security/advisories)
to tell us about any security issues you found in ACME. We will get back
to you in less than 14 days.
